Struct ModifiersKeys
pub struct ModifiersKeys(/* private fields */);Implementations
impl ModifiersKeys
impl ModifiersKeys
pub const LSHIFT: ModifiersKeys
pub const RSHIFT: ModifiersKeys
pub const LCONTROL: ModifiersKeys
pub const RCONTROL: ModifiersKeys
pub const LALT: ModifiersKeys
pub const RALT: ModifiersKeys
pub const LMETA: ModifiersKeys
pub const RMETA: ModifiersKeys
pub const LSUPER: ModifiersKeys
pub const RSUPER: ModifiersKeys
impl ModifiersKeys
impl ModifiersKeys
pub const fn empty() -> ModifiersKeys
pub const fn empty() -> ModifiersKeys
Get a flags value with all bits unset.
pub const fn all() -> ModifiersKeys
pub const fn all() -> ModifiersKeys
Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<ModifiersKeys>
pub const fn from_bits(bits: u8) -> Option<ModifiersKeys>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> ModifiersKeys
pub const fn from_bits_truncate(bits: u8) -> ModifiersKeys
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> ModifiersKeys
pub const fn from_bits_retain(bits: u8) -> ModifiersKeys
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ModifiersKeys>
pub fn from_name(name: &str) -> Option<ModifiersKeys>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: ModifiersKeys) -> bool
pub const fn intersects(&self, other: ModifiersKeys) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ModifiersKeys) -> bool
pub const fn contains(&self, other: ModifiersKeys) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: ModifiersKeys)
pub fn insert(&mut self, other: ModifiersKeys)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: ModifiersKeys)
pub fn remove(&mut self, other: ModifiersKeys)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: ModifiersKeys)
pub fn toggle(&mut self, other: ModifiersKeys)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: ModifiersKeys, value: bool)
pub fn set(&mut self, other: ModifiersKeys, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: ModifiersKeys) -> ModifiersKeys
pub const fn intersection(self, other: ModifiersKeys) -> ModifiersKeys
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ModifiersKeys) -> ModifiersKeys
pub const fn union(self, other: ModifiersKeys) -> ModifiersKeys
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: ModifiersKeys) -> ModifiersKeys
pub const fn difference(self, other: ModifiersKeys) -> ModifiersKeys
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: ModifiersKeys) -> ModifiersKeys
pub const fn symmetric_difference(self, other: ModifiersKeys) -> ModifiersKeys
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ModifiersKeys
pub const fn complement(self) -> ModifiersKeys
The bitwise negation (!) of the bits in self, truncating the result.
impl ModifiersKeys
impl ModifiersKeys
pub const fn iter(&self) -> Iter<ModifiersKeys>
pub const fn iter(&self) -> Iter<ModifiersKeys>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ModifiersKeys>
pub const fn iter_names(&self) -> IterNames<ModifiersKeys>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.