ModifiersState

Struct ModifiersState 

pub struct ModifiersState(/* private fields */);
Represents the current logical state of the keyboard modifiers

Each flag represents a modifier and is set if this modifier is active.

Note that the modifier key can be physically released with the modifier still being marked as active, as in the case of sticky modifiers. See ModifiersKeyState for more details on what “sticky” means.

Implementations



impl ModifiersState

pub const SHIFT: ModifiersState

The “shift” key.

pub const CONTROL: ModifiersState

The “control” key.

pub const ALT: ModifiersState

The “alt” key.

pub const META: ModifiersState

This is the “windows” key on PC and “command” key on Mac.

pub const SUPER: ModifiersState

👎Deprecated: use META instead


impl ModifiersState

pub const fn empty() -> ModifiersState

Get a flags value with all bits unset.

pub const fn all() -> ModifiersState

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<ModifiersState>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> ModifiersState

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> ModifiersState

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<ModifiersState>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: ModifiersState) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: ModifiersState) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: ModifiersState)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: ModifiersState)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: ModifiersState)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: ModifiersState, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: ModifiersState) -> ModifiersState

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: ModifiersState) -> ModifiersState

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: ModifiersState) -> ModifiersState

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: ModifiersState) -> ModifiersState

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> ModifiersState

The bitwise negation (!) of the bits in self, truncating the result.



impl ModifiersState

pub const fn iter(&self) -> Iter<ModifiersState>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ModifiersState>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.



impl ModifiersState

pub fn shift_key(&self) -> bool

Returns whether the shift modifier is active.

pub fn control_key(&self) -> bool

Returns whether the control modifier is active.

pub fn alt_key(&self) -> bool

Returns whether the alt modifier is active.

pub fn meta_key(&self) -> bool

Returns whether the meta modifier is active.